@@ -24,7 +24,7 @@
 #include <kate/application.h>
 #include <kate/view.h>
 #include <kate/document.h>
-#include <kate/docmanager.h>
+#include <kate/documentmanager.h>
 #include <kate/mainwindow.h>
 #include <kate/viewmanager.h>
 
@@ -51,9 +51,11 @@ public:
   PluginKateHtmlTools( QObject* parent = 0, const char* name = 0 );
   virtual ~PluginKateHtmlTools();
 
-  Kate::PluginView *createView (Kate::MainWindow *win);
+  void addView (Kate::MainWindow *win);
+  void removeView (Kate::MainWindow *win);
 
-private:
+private: 
+  QPtrList<class PluginView> m_views; 
 
   QString KatePrompt (const QString & strTitle, const QString &strPrompt,
 			     QWidget * that);
