@@ -19,8 +19,10 @@
 #define _PLUGIN_KATE_INSERT_COMMAND_H_
 
 #include <kate/application.h>
-#include <kate/docmanager.h>
-#include <kate/document.h>
+#include <kate/documentmanager.h>
+#include <kate/document.h>  
+#include <kate/pluginconfiginterface.h>
+#include <kate/pluginconfiginterfaceextension.h>
 #include <kate/mainwindow.h>
 #include <kate/plugin.h>
 #include <kate/view.h>
@@ -62,7 +64,7 @@ class KatePluginFactory : public KLibFactory
     static KInstance* s_instance;
 };
 
-class PluginKateInsertCommand : public Kate::Plugin
+class PluginKateInsertCommand : public Kate::Plugin, Kate::PluginViewInterface, Kate::PluginConfigInterfaceExtension
 {
   Q_OBJECT
 
@@ -70,16 +72,19 @@ class PluginKateInsertCommand : public Kate::Plugin
     PluginKateInsertCommand( QObject* parent = 0, const char* name = 0 );
     virtual ~PluginKateInsertCommand();
 
-    Kate::PluginView *createView (Kate::MainWindow *win);
-    Kate::View *kv;
+    void addView (Kate::MainWindow *win);
+    void removeView (Kate::MainWindow *win);
+      
+      Kate::View *kv;
 
-    WaitDlg *wdlg;
+    WaitDlg *wdlg;            
+    QPtrList<class PluginView> m_views;      
 
-    bool hasConfigPage() { return true; }
-    Kate::PluginConfigPage *createConfigPage (QWidget *w);
-    QString configPageName() { return i18n("Insert Command"); };
-    QString configPageTitle() { return i18n("Configure Insert Command Plugin"); };
-    //QPixmap configPageIcon() { return 0L; };
+    uint configPages () const { return 1; }
+    Kate::PluginConfigPage *configPage (uint , QWidget *w, const char *name=0);
+    QString configPageName(uint) const { return i18n("Insert Command"); };
+    QString configPageFullName(uint) const { return i18n("Configure Insert Command Plugin"); };
+    QPixmap configPagePixmap (uint number = 0, int size = KIcon::SizeSmall) const { return 0L; };
 
   private:
     void initConfigPage( InsertCommandConfigPage* );
@@ -147,8 +152,11 @@ class InsertCommandConfigPage : public Kate::PluginConfigPage
     /** Reimplemented from Kate::PluginConfigPage
      * just emits configPageApplyRequest( this ).
      */
-    void applyConfig();
-
+    void apply();          
+    
+    void reset () { ; };
+    void defaults () { ; };
+    
   signals:
     /** Ask the plugin to set initial values */
     void configPageApplyRequest( InsertCommandConfigPage* );
