@@ -18,9 +18,9 @@
 #include "plugin_katetextfilter.h"
 #include "plugin_katetextfilter.moc"
 
-#include <qinputdialog.h>
 #include <kaction.h>
 #include <kinstance.h>
+#include <klineeditdlg.h>
 #include <kmessagebox.h>
 #include <klocale.h>
 #include <cassert>
@@ -28,6 +28,14 @@
 #include <qstring.h>
 
 #define POP_(x) kdDebug(13000) << #x " = " << flush << x << endl
+              
+class PluginView : public KXMLGUIClient
+{             
+  friend class PluginKateTextFilter;
+
+  public:
+    Kate::MainWindow *win;
+};
 
 extern "C"
 {
@@ -57,7 +65,7 @@ KInstance* KatePluginFactory::s_instance = 0L;
 
 
 PluginKateTextFilter::PluginKateTextFilter( QObject* parent, const char* name )
-    : Kate::Plugin ( parent, name ),
+    : Kate::Plugin ( (Kate::Application *)parent, name ),
   m_pFilterShellProcess (NULL)
 {
 }
@@ -67,16 +75,32 @@ PluginKateTextFilter::~PluginKateTextFilter()
   delete m_pFilterShellProcess;
 }
 
-Kate::PluginView *PluginKateTextFilter::createView (Kate::MainWindow *win)
+void PluginKateTextFilter::addView(Kate::MainWindow *win)
 {
-   Kate::PluginView *view = new Kate::PluginView (this, win);
+    // TODO: doesn't this have to be deleted?
+    PluginView *view = new PluginView ();
 
-  (void)  new KAction ( i18n("Fi&lter Text..."), /*"edit_filter",*/ CTRL + Key_Backslash, this,
+    (void)  new KAction ( i18n("Filter Te&xt..."), /*"edit_filter",*/ CTRL + Key_Backslash, this,
   SLOT( slotEditFilter() ), view->actionCollection(), "edit_filter" );
+             
+    view->setInstance (new KInstance("kate"));
+    view->setXMLFile( "plugins/katetextfilter/ui.rc" );
+    win->guiFactory()->addClient (view);
+    view->win = win; 
+    
+   m_views.append (view);
+}   
 
-   view->setXML( "plugins/katetextfilter/ui.rc" );
-
-   return view;
+void PluginKateTextFilter::removeView(Kate::MainWindow *win)
+{
+  for (uint z=0; z < m_views.count(); z++)
+    if (m_views.at(z)->win == win)
+    {
+      PluginView *view = m_views.at(z);
+      m_views.remove (view);
+      win->guiFactory()->removeClient (view);
+      delete view;
+    }  
 }
 
         void
@@ -150,25 +174,16 @@ KatePrompt
         QWidget * that
         )
 {
-
-  bool ok (false);
-
   //  TODO: Make this a "memory edit" field with a combo box
   //  containing prior entries
 
-  QString text ( QInputDialog::getText
-                        (
-                        strTitle,
-                        strPrompt,
-                        QLineEdit::Normal,
-                        QString::null,
-                        &ok,
-                        that
-                        ) );
-
-  if (!ok)  text = "";
-  return text;
+  KLineEditDlg dlg(strPrompt, QString::null, that);
+  dlg.setCaption(strTitle);
 
+  if (dlg.exec())
+    return dlg.text();
+  else
+    return "";
 }
 
 
@@ -202,7 +217,7 @@ PluginKateTextFilter::slotFilterProcessExited (KProcess * pProcess)
 {
 
 	assert (pProcess == m_pFilterShellProcess);
-	Kate::View * kv (myApp->getViewManager()->getActiveView());
+	Kate::View * kv (application()->activeMainWindow()->viewManager()->activeView());
 	if (!kv) return;
 	QString marked = kv->getDoc()->selection ();
 	if (marked.length() > 0)
@@ -245,12 +260,12 @@ PluginKateTextFilter::slotFilterCloseStdin (KProcess * pProcess)
                  void
 PluginKateTextFilter::slotEditFilter ()  //  PCP
 {
-  Kate::View * kv (myApp->getViewManager()->getActiveView());
+  Kate::View * kv (application()->activeMainWindow()->viewManager()->activeView());
   if (!kv) return;
 
   QString text ( KatePrompt ( i18n("Filter"),
-                        i18n("Enter command to pipe selected text through"),
-                        (QWidget*)  myApp->getViewManager()->getActiveView()
+                        i18n("Enter command to pipe selected text through:"),
+                        (QWidget*)  kv
                         ) );
 
   if ( !text.isEmpty () )
