@@ -46,6 +46,15 @@ PluginBabelFish::PluginBabelFish( QObject* parent, const char* name,
   menu->insert( new KAction( i18n("English to Italian"), 0,
                              this, SLOT(translateURL()),
                              actionCollection(), "en_it") );
+  menu->insert( new KAction( i18n("English to Japanese"), 0,
+                             this, SLOT(translateURL()),
+                             actionCollection(), "en_ja") );
+  menu->insert( new KAction( i18n("English to Korean"), 0,
+                             this, SLOT(translateURL()),
+                             actionCollection(), "en_ko") );
+  menu->insert( new KAction( i18n("English to Chinese"), 0,
+                             this, SLOT(translateURL()),
+                             actionCollection(), "en_zh") );
   menu->insert( new KAction( i18n("English to Portuguese"), 0,
                              this, SLOT(translateURL()),
                              actionCollection(), "en_pt") );
@@ -61,6 +70,15 @@ PluginBabelFish::PluginBabelFish( QObject* parent, const char* name,
   menu->insert( new KAction( i18n("Italian to English"), 0,
                              this, SLOT(translateURL()),
                              actionCollection(), "it_en") );
+  menu->insert( new KAction( i18n("Japanese to English"), 0,
+                             this, SLOT(translateURL()),
+                             actionCollection(), "ja_en") );
+  menu->insert( new KAction( i18n("Korean to English"), 0,
+                             this, SLOT(translateURL()),
+                             actionCollection(), "ko_en") );
+  menu->insert( new KAction( i18n("Chinese to English"), 0,
+                             this, SLOT(translateURL()),
+                             actionCollection(), "zh_en") );
   menu->insert( new KAction( i18n("Portuguese to English"), 0,
                              this, SLOT(translateURL()),
                              actionCollection(), "pt_en") );
@@ -92,15 +110,17 @@ void PluginBabelFish::translateURL()
   if ( !parent()->inherits("KHTMLPart") )
   {
     QString title = i18n( "Cannot translate source" );
-    QString text = i18n( "You cannot translate anything except web pages with "
-                         "this plugin, sorry." );
+    QString text = i18n( "Only web pages can be translated using "
+                         "this plugin." );
 
     KMessageBox::sorry( 0L, text, title );
     return;
   }
 
   // Get URL
-  KHTMLPart *part = static_cast<KHTMLPart *>(parent());
+  KHTMLPart *part = dynamic_cast<KHTMLPart *>(parent());
+  if ( !part )
+    return;
 
   QString query;
   // we check if we have text selected.  if so, we translate that.  if
@@ -110,7 +130,7 @@ void PluginBabelFish::translateURL()
   else
   {
     KURL url = part->url();
-    query = "urltext=" + KURL::encode_string( url.url() );
+    query = "url=" + KURL::encode_string( url.url() );
 
     // Check syntax
     if ( url.isMalformed() )
@@ -124,7 +144,7 @@ void PluginBabelFish::translateURL()
   }
 
   // Create babelfish URL
-  KURL babel( "http://babel.altavista.com/translate.dyn" );
+  KURL babel( "http://babelfish.altavista.com/babelfish/tr" );
 
   // Handle the language
   query += "&lp=";
@@ -133,7 +153,7 @@ void PluginBabelFish::translateURL()
   babel.setQuery( query );
 
   // Connect to the fish
-  part->openURL( babel );
+  emit part->browserExtension()->openURLRequest( babel );
 }
 
 #include <plugin_babelfish.moc>
