@@ -44,7 +44,7 @@ K_EXPORT_COMPONENT_FACTORY(libdirfilterplugin,
                            DirFilterFactory("dirfilterplugin"));
 
 SessionManager* SessionManager::m_self = 0;
-KStaticDeleter<SessionManager> dirfiltersd;
+static KStaticDeleter<SessionManager> dirfiltersd;
 
 
 SessionManager *SessionManager::self ()
@@ -135,7 +135,7 @@ DirFilterPlugin::DirFilterPlugin (QObject* parent, const char* name,
 {
   m_part = 0L;
 
-  m_pFilterMenu = new KActionMenu (i18n("View &Filter"), "filter",
+  m_pFilterMenu = new KActionMenu (i18n("View F&ilter"), "filter",
                                    actionCollection(), "filterdir");
   m_pFilterMenu->setDelayed (false);
 
@@ -168,6 +168,9 @@ void DirFilterPlugin::slotOpenURL ()
 {
   KURL url = m_part->url();
 
+  kdDebug() << "DirFilterPlugin: New URL    : " << url.url() << endl;
+  kdDebug() << "DirFilterPlugin: Current URL: " << m_pURL.url() << endl;
+
   if (m_pURL != url)
   {
     m_pURL = url;
@@ -195,7 +198,7 @@ void DirFilterPlugin::slotShowPopup()
   enableReset = 0;
 
   m_pFilterMenu->popupMenu()->clear();
-  m_pFilterMenu->popupMenu()->insertTitle (i18n("Only show items of type:"));
+  m_pFilterMenu->popupMenu()->insertTitle (i18n("Only Show Items of Type"));
 
   MimeInfoIterator it = m_pMimeInfo.begin();
   for (; it != m_pMimeInfo.end() ; ++it)
@@ -268,8 +271,9 @@ void DirFilterPlugin::slotShowPopup()
   m_pFilterMenu->popupMenu()->setItemChecked (id, !enableReset &&
                                               SessionManager::self()->useMultipleFilters);
 
-  label = SessionManager::self()->showCount ? i18n("Hide Count"):i18n("Show Count");
-  m_pFilterMenu->popupMenu()->insertItem (label, this, SLOT(slotShowCount()));
+  id = m_pFilterMenu->popupMenu()->insertItem (i18n("Show Count"), this,
+                                               SLOT(slotShowCount()));
+  m_pFilterMenu->popupMenu()->setItemChecked (id, SessionManager::self()->showCount);
 
   id = m_pFilterMenu->popupMenu()->insertItem (i18n("Reset"), this,
                                                SLOT(slotReset()));
@@ -335,6 +339,11 @@ void DirFilterPlugin::slotItemsAdded (const KFileItemList& list)
     return;
   }
 
+  // Make sure the filter list is enabled once a named 
+  // filter is removed.
+  if (!m_pFilterMenu->isEnabled())
+    m_pFilterMenu->setEnabled (true);  
+  
   KFileItemListIterator it (list);
   for (; it.current () ; ++it)
   {
