@@ -34,7 +34,7 @@ Boston, MA 02111-1307, USA.
 #include <kcharsets.h>
 #include <kmessagebox.h>
 #include <kurl.h>
-#include <kapp.h>
+#include <kapplication.h>
 #include <kdebug.h>
 #include <kgenericfactory.h>
 
@@ -46,7 +46,7 @@ K_EXPORT_COMPONENT_FACTORY( libkimgallery, KImGalleryPluginFactory( "imgallerypl
 KImGalleryPlugin::KImGalleryPlugin( QObject* parent, const char* name, const QStringList & )
   : KParts::Plugin( parent, name ), m_commentMap(0)
 {
-  new KAction( i18n( "&Create Image Gallery" ), "imagegallery", CTRL+Key_I, this,
+  new KAction( i18n( "&Create Image Gallery..." ), "imagegallery", CTRL+Key_I, this,
 	       SLOT( slotExecute() ), actionCollection(), "create_img_gallery" );
 }
 
@@ -59,15 +59,14 @@ void KImGalleryPlugin::slotExecute()
            return;
    }
    m_part = static_cast<KonqDirPart *>(parent());
- if (!m_part->url().isLocalFile()) {	//TODO support remote URLs too?
+  if (!m_part->url().isLocalFile()) {	//TODO support remote URLs too?
     KMessageBox::sorry(m_part->widget(), i18n("Creating an image gallery works only on local directories."));
     return;
   }
   kdDebug() << "dialog is ok" << endl;
   m_configDlg = new KIGPDialog(m_part->widget(), m_part->url().path(+1));
-  m_configDlg->exec();
 
-  if (m_configDlg->isDialogOk()) {
+  if ( m_configDlg->exec() == QDialog::Accepted ) {
     kdDebug() << "dialog is ok" << endl;
     m_copyFiles = m_configDlg->copyOriginalFiles();
     m_recurseSubDirectories = m_configDlg->recurseSubDirectories();
@@ -116,7 +115,7 @@ void KImGalleryPlugin::createHead(QTextStream& stream)
   QString chsetName = QTextCodec::codecForLocale()->mimeName();
 
   if (m_configDlg->generateXHTML()) {
-    stream << "<?xml version=\"1.0\" charset=\"iso-8859-1\" ?>"<< endl;
+    stream << "<?xml version=\"1.0\" charset=\"" +  chsetName + "\" ?>" << endl;
     stream << "<!DOCTYPE html PUBLIC \"-//W3C//DTD XHTML 1.0 Strict//EN\" \"DTD/xhtml1-strict.dtd\">" << endl;
     stream << "<html xmlns=\"http://www.w3.org/1999/xhtml\">" << endl;
   } else {
@@ -165,18 +164,20 @@ void KImGalleryPlugin::createBody(QTextStream& stream, const QString& sourceDirN
   if (m_recurseSubDirectories && subDirList.count() > 2) { //subDirList.count() is always >= 2 because of the "." and ".." directories
     stream << i18n("<i>Subdirectories</i>:") << "<br>" << endl;
     for (QStringList::ConstIterator it = subDirList.begin(); it != subDirList.end(); it++) {
-      if (*it == "." || *it == "..") {
-	continue; //disregard the "." and ".." directories
-      }
-      stream << "<a href=\"" << *it << "/" << url.fileName() << "\">" << *it << "</a><br>" << endl;
+      if (*it == "." || *it == "..")
+        continue; //disregard the "." and ".." directories
+      stream << "<a href=\"" << *it << "/" << url.fileName()
+          << "\">" << *it << "</a><br>" << endl;
     }
-    stream << "<hr>" << endl;
+    if (m_configDlg->generateXHTML())
+      stream << "<hr>" << endl;
+    else
+      stream << "<hr/>" << endl;
   }
 
   stream << "<center>\n<table>" << endl;
 
   //table with images
-  stream << "<table>" <<endl;
   int imgIndex;
   QFileInfo imginfo;
   QPixmap  imgProp;
@@ -214,7 +215,7 @@ void KImGalleryPlugin::createBody(QTextStream& stream, const QString& sourceDirN
 
 	if (m_configDlg->printImageSize()) {
 	  imginfo.setFile( imageDir, imgName );
-	  stream << "<div> (" << (imginfo.size() / 1024) <<" Kb)" << "</div>" << endl;
+	  stream << "<div>(" << (imginfo.size() / 1024) << " " <<  i18n("KB") << ") " << "</div>" << endl;
 	}
 
 	if (m_useCommentFile) {
@@ -243,9 +244,11 @@ bool KImGalleryPlugin::createHtml(const KURL& url, const QString& sourceDirName,
 {
   if(m_cancelled) return false;
 
+
   if( !parent() || !parent()->inherits("KonqDirPart"))
         return false;
   KonqDirPart * part = static_cast<KonqDirPart *>(parent());
+
   QStringList subDirList;
   if (m_recurseSubDirectories && (recursionLevel >= 0)) { //recursionLevel == 0 means endless
     QDir toplevel_dir = QDir( sourceDirName );
@@ -275,7 +278,7 @@ bool KImGalleryPlugin::createHtml(const KURL& url, const QString& sourceDirName,
   }
 
   kdDebug() << "sourceDirName: " << sourceDirName << endl;
-  QDir imageDir( sourceDirName, "*.png *.PNG *.gif *.GIF *.jpg *.JPG *.jpeg *.JPEG",
+  QDir imageDir( sourceDirName, "*.png *.PNG *.gif *.GIF *.jpg *.JPG *.jpeg *.JPEG *.bmp *.BMP",
 		 QDir::Name|QDir::IgnoreCase, QDir::Files|QDir::Readable);
 
   const QString imgGalleryDir = url.directory();
@@ -294,7 +297,7 @@ bool KImGalleryPlugin::createHtml(const KURL& url, const QString& sourceDirName,
   }
 
   QFile file( url.path() );
-  kdDebug() << "url.path(): " << url.path()  << ", thumb_dir: "<< thumb_dir.path()
+  kdDebug() << "url.path(): " << url.path() << ", thumb_dir: "<< thumb_dir.path()
 	    << ", imageDir: "<< imageDir.path() << endl;
 
   if ( imageDir.exists() && file.open(IO_WriteOnly) ) {
@@ -335,7 +338,7 @@ void KImGalleryPlugin::deleteCancelledGallery(const KURL& url, const QString& so
   const QString imgGalleryDir = url.directory();
   QDir thumb_dir( imgGalleryDir + QString::fromLatin1("/thumbs/"));
   QDir images_dir( imgGalleryDir + QString::fromLatin1("/images/"));
-  QDir imageDir( sourceDirName, "*.png *.PNG *.gif *.GIF *.jpg *.JPG *.jpeg *.JPEG",
+  QDir imageDir( sourceDirName, "*.png *.PNG *.gif *.GIF *.jpg *.JPG *.jpeg *.JPEG *.bmp *.BMP",
 		 QDir::Name|QDir::IgnoreCase, QDir::Files|QDir::Readable);
   QFile file( url.path() );
 
