@@ -204,6 +204,23 @@ void UAChangerPlugin::slotAboutToShow()
                                       SLOT(slotDefault()), 0, ++count );
   m_pUAMenu->popupMenu()->setItemEnabled(count, (proto.defaultUserAgent()!=
                                                  m_currentUserAgent));
+  m_pUAMenu->popupMenu()->insertSeparator();
+
+  m_pUAMenu->popupMenu()->insertItem( i18n("Apply to Entire Site"), this,
+                                      SLOT(slotApplyToDomain()),
+                                      0, ++count );  
+  m_pUAMenu->popupMenu()->setItemChecked(count, m_bApplyToDomain);
+
+  m_pUAMenu->popupMenu()->insertItem( i18n("Configure..."), this,
+                                      SLOT(slotConfigure()));
+
+}
+
+void UAChangerPlugin::slotConfigure()
+{
+  KService::Ptr service = KService::serviceByDesktopName ("useragent");
+  if (service)
+    KRun::runCommand (service->exec ());
 }
 
 void UAChangerPlugin::slotItemSelected( int id )
@@ -215,7 +232,7 @@ void UAChangerPlugin::slotItemSelected( int id )
     m_currentUserAgent = m_lstIdentity[id];
     host = filterHost( m_currentURL.host() );
 
-    m_config->setGroup( host );
+    m_config->setGroup( host.lower() );
     m_config->writeEntry( "UserAgent", m_currentUserAgent );
     m_config->sync();
 
@@ -256,6 +273,7 @@ void UAChangerPlugin::slotDefault()
 
   for (QStringList::Iterator it = domains.begin(); it != domains.end(); it++)
   {
+    kdDebug () << "Domain to remove: " << *it << endl;
     if ( m_config->hasGroup(*it) )
       m_config->deleteGroup(*it);
     else if( m_config->hasKey(*it) )
@@ -282,14 +300,14 @@ void UAChangerPlugin::updateIOSlaves ()
 
   if (!client->attach())
     kdDebug() << "Can't connect with DCOP server." << endl;
-  
-      QByteArray data;
-      QDataStream stream( data, IO_WriteOnly );
+
+  QByteArray data;
+  QDataStream stream( data, IO_WriteOnly );
   stream << QString::null;
   client->send( "*", "KIO::Scheduler", "reparseSlaveConfiguration(QString)",
                 data );
   delete client;
-  }
+}
 
 QString UAChangerPlugin::filterHost(const QString &hostname)
 {
@@ -310,8 +328,8 @@ QString UAChangerPlugin::filterHost(const QString &hostname)
   if (isIPAddress)
     return hostname;
 
-  // Return the TLD...
-  return findTLD(hostname);
+  // Return the TLD if apply to domain or 
+  return (m_bApplyToDomain ? findTLD(hostname): hostname);
 }
 
 
@@ -319,7 +337,7 @@ QString UAChangerPlugin::filterHost(const QString &hostname)
 QString UAChangerPlugin::findTLD (const QString &hostname)
 {
   QString tld = hostname;
-  
+
   if ( !tld.isEmpty () )
   {
     QStringList partList = QStringList::split('.', tld, false);
@@ -328,54 +346,54 @@ QString UAChangerPlugin::findTLD (const QString &hostname)
     if (count > 2)
     {
       QStringList tlds;
-      
+
       // Classical TLD's
       tlds << "com" << "net" << "org" << "gov" << "edu" << "mil" << "int";
-      
+
       // The new seven TLD's
       tlds << "aero" << "biz" << "coop" << "info" << "museum" << "name" << "pro";
-      
+
       QStringList::Iterator topTLD = partList.fromLast ();
-      
+
       if ( (*topTLD).length() < 3 )
       {
         --topTLD;
-        
+
         if ( (*topTLD).length () < 3 )
         {
           --topTLD;
-          
+
           // Remove anymore known TLD's...
           while ( topTLD != partList.begin() && tlds.findIndex (*topTLD) != -1 )
-            --topTLD;          
-                   
+            --topTLD;
+
           // Remove everything upto this point...
           partList.erase (partList.begin(), topTLD);
-          
+
           // If we still have something, then create a TLD out of it.
           if (partList.count ()) 
             tld = partList.join (".");
-    }
+        }
         else
         {
           while ( topTLD != partList.begin() && tlds.findIndex (*topTLD) != -1 )
             --topTLD;
-          
+
           partList.erase (partList.begin(), topTLD);
-          
+
           if (partList.count ())
-            tld = partList.join (".");          
+            tld = partList.join (".");
         }
       }
       else
       {
         --topTLD;
-        
+
         while ( topTLD != partList.begin () && tlds.findIndex (*topTLD) != -1 )
           --topTLD;
-          
+
         partList.erase (partList.begin (), topTLD);
-        
+
         if (partList.count())
           tld = partList.join (".");
       }
@@ -387,18 +405,25 @@ QString UAChangerPlugin::findTLD (const QString &hostname)
 
 void UAChangerPlugin::saveSettings()
 {
-  if(!m_bSettingsLoaded)
-    return;
+  if(!m_bSettingsLoaded) return;
 
   KConfig cfg ("uachangerrc", false, false);
   cfg.setGroup ("General");
+
+  cfg.writeEntry ("applyToDomain", m_bApplyToDomain);
 }
 
 void UAChangerPlugin::loadSettings()
 {
   KConfig cfg ("uachangerrc", false, false);
   cfg.setGroup ("General");
+
+  m_bApplyToDomain = cfg.readBoolEntry ("applyToDomain", true);
   m_bSettingsLoaded = true;
 }
 
+void UAChangerPlugin::slotApplyToDomain()
+{
+  m_bApplyToDomain = !m_bApplyToDomain;
+}
 #include "uachangerplugin.moc"
