@@ -24,7 +24,7 @@
  *  Boston, MA 02111-1307, USA.
  **/
 
-/* $Id: plugin_validators.cpp,v 1.10 2002/03/06 10:17:16 asimon Exp $ */
+/* $Id: plugin_validators.cpp,v 1.16 2002/09/01 23:15:54 mhunter Exp $ */
 
 #include <kinstance.h>
 #include <kmessagebox.h>
@@ -43,25 +43,25 @@ K_EXPORT_COMPONENT_FACTORY( libvalidatorsplugin,
 
 PluginValidators::PluginValidators( QObject* parent, const char* name,
                                     const QStringList & )
-  : Plugin( parent, name ), m_part(0), m_configDialog(0)
+  : Plugin( parent, name ), m_configDialog(0), m_part(0)
 {
   m_menu = new KActionMenu ( i18n( "&Validate Web Page" ), "validators",
 			     actionCollection(), "validateWebpage" );
   m_menu->setDelayed( false );
 
-  m_menu->insert( new KAction( i18n( "&Validate HTML" ), 
+  m_menu->insert( new KAction( i18n( "Validate &HTML" ), 
 			       "htmlvalidator", 0,
 			       this, SLOT(slotValidateHTML()),
 			       actionCollection(), "validateHTML") );
 
-  m_menu->insert( new KAction( i18n( "&Validate CSS" ),
+  m_menu->insert( new KAction( i18n( "Validate &CSS" ),
 			       "cssvalidator", 0,
 			       this, SLOT(slotValidateCSS()),
 			       actionCollection(), "validateCSS") );  
 
   if ( parent && parent->inherits( "KHTMLPart" ))
     {
-      m_menu->insert( new KAction( i18n( "&Configure Validator..." ),
+      m_menu->insert( new KAction( i18n( "C&onfigure Validator..." ),
 				   "configure", 0,
 				   this, SLOT(slotConfigure()),
 				   actionCollection(), "configure") );
@@ -109,7 +109,7 @@ void PluginValidators::slotConfigure()
   this->setURLs();
 }
 
-void PluginValidators::validateURL(KURL url, KURL uploadUrl)
+void PluginValidators::validateURL(const KURL &url, const KURL &uploadUrl)
 { 
   // The parent is assumed to be a KHTMLPart
   if ( !parent()->inherits("KHTMLPart") )
@@ -141,6 +141,16 @@ void PluginValidators::validateURL(KURL url, KURL uploadUrl)
     } 
   else 
     {
+      if (partUrl.hasPass())
+        {
+          KMessageBox::sorry(
+          	m_part->widget(),
+          	i18n("<qt>The selected URL cannot be verified because it contains "
+          	     "a password. Sending this URL to <b>%1</b> would put the security "
+          	     "of <b>%2</b> at risk.</qt>")
+          	     .arg(validatorUrl.host()).arg(partUrl.host()));
+          return;
+        }
       // Set entered URL as a parameter
       QString q = partUrl.url();
       q = KURL::encode_string( q );
