@@ -24,7 +24,7 @@
  *  Boston, MA 02111-1307, USA.
  **/
 
-/* $Id: plugin_validators.h,v 1.4 2001/11/02 21:03:07 schlpbch Exp $ */
+/* $Id: plugin_validators.h,v 1.6 2002/05/01 05:15:24 raabe Exp $ */
 
 #ifndef __plugin_validators_h
 #define __plugin_validators_h
@@ -52,14 +52,15 @@ public slots:
 
 private: 
   KActionMenu *m_menu;
-  ValidatorsDialog *m_configDialog;
-
-  KHTMLPart* m_part;
+  ValidatorsDialog *m_configDialog; // |
+                                    // +-> Order dependency.
+  KHTMLPart* m_part;                // |
+  
   KURL m_WWWValidatorUrl, m_WWWValidatorUploadUrl;
   KURL m_CSSValidatorUrl, m_CSSValidatorUploadUrl;
 
   void setURLs();
-  void validateURL(KURL url, KURL uploadUrl);
+  void validateURL(const KURL &url, const KURL &uploadUrl);
 };
 
 #endif
