@@ -17,7 +17,7 @@
  *  Boston, MA 02111-1307, USA.
  **/
 
-/* $Id: plugin_webarchiver.cpp,v 1.17.2.2 2002/06/14 07:49:44 mlaurent Exp $ */
+/* $Id: plugin_webarchiver.cpp,v 1.23 2002/08/24 23:40:58 cumming Exp $ */
 
 /* 
  * There are two recursions within this code:
@@ -56,7 +56,7 @@ PluginWebArchiver::PluginWebArchiver( QObject* parent, const char* name,
                                       const QStringList & )
   : Plugin( parent, name ), m_bPreserveWS(false)
 {
-  (void) new KAction( i18n("&Archive Web Page"),
+  (void) new KAction( i18n("Ar&chive Web Page..."),
                       "webarchiver", 0,
                       this, SLOT(slotSaveToArchive()),
                       actionCollection(), "archivepage" );
@@ -75,9 +75,12 @@ void PluginWebArchiver::slotSaveToArchive()
   
   QString archiveName = QString::fromUtf8(part->htmlDocument().title().string().utf8());
 
+  if (archiveName.isEmpty())
+    archiveName = i18n("Untitled");
+
   // Replace space with underscore, proposed Frank Pieczynski <pieczy@knuut.de>
   archiveName = archiveName.simplifyWhiteSpace().replace( QRegExp("\\s+"), "_");
- 
+
   archiveName = QDir::homeDirPath() + "/" + archiveName + ".war"; //Thanks ade
 
   KURL url = KFileDialog::getSaveFileName(archiveName, "*.tgz *.war|Web Archives", part->widget(), 
@@ -118,6 +121,7 @@ void PluginWebArchiver::slotSaveToArchive()
     delete m_downloadedURLDict;
 
     m_tarBall->close();
+
     KMessageBox::information(part->widget(), i18n( "Archiving webpage completed." ), 
 			     QString::null, QString::null, false);  
 #ifdef DEBUG_WAR
@@ -125,8 +129,8 @@ void PluginWebArchiver::slotSaveToArchive()
 #endif
 
   } else {
-    const QString title = i18n( "Couldn't open Web-Archive" );
-    const QString text = i18n( "Sorry, couldn't open \n %1 \n for writing." ).arg(url.path());
+    const QString title = i18n( "Unable to open Web-Archive" );
+    const QString text = i18n( "Unable to open \n %1 \n for writing." ).arg(url.path());
     KMessageBox::sorry( part->widget(), text, title );
   }
   delete m_tarBall;
@@ -189,6 +193,7 @@ void PluginWebArchiver::saveArchiveRecursive(const DOM::Node &pNode, const KURL&
   QString strIndent;
   strIndent.fill(' ', indent);  
   const DOM::Element element = (const DOM::Element) pNode;
+  DOM::Node child;
 
   if ( !element.isNull() ) {
     if (nodeName.at(0)=='-') {
@@ -283,7 +288,17 @@ void PluginWebArchiver::saveArchiveRecursive(const DOM::Node &pNode, const KURL&
     }
   }
 
-  DOM::Node child = pNode.firstChild();
+  try 
+  {
+    // We might throw a DOM exception
+    child = pNode.firstChild();
+  }
+  catch (...)
+  {
+    // No children, stop recursion here
+    child = DOM::Node();
+  }
+
   while(!child.isNull()) {
     saveArchiveRecursive(child, baseURL, _textStream, indent+2);
     child = child.nextSibling();
