@@ -17,7 +17,7 @@
    Boston, MA 02111-1307, USA.
 */
 
-// $Id: webarchivecreator.cpp,v 1.2 2001/08/10 11:56:45 mueller Exp $
+// $Id: webarchivecreator.cpp,v 1.3 2002/04/03 14:55:34 mlaurent Exp $
 
 #include <time.h>
 
@@ -25,7 +25,7 @@
 #include <qimage.h>
 #include <qpainter.h>
 
-#include <kapp.h>
+#include <kapplication.h>
 #include <khtml_part.h>
 
 #include "webarchivecreator.moc"
