@@ -3,8 +3,8 @@
  ** Copyright (c) 2001, Flaming Sword Productions
  ** All Rights Reserved under the BSD License
  **/
-#ifndef __KOSD_H__
-#define __KOSD_H__
+#ifndef KOSDH
+#define KOSDH
 #include <sys/types.h>
 #include <qqueue.h>
 #include <qobject.h>
@@ -24,18 +24,26 @@ public:
 		Paused = 2
 	};
 
-	enum Position
+	enum HorizontalPosition
 	{
-		Bottom,
-		Top
+		Top = 0,
+		Center = 1,
+		Bottom = 2
+	};
+
+	enum VerticalPosition
+	{
+		Left = 0,
+		VerticalCenter = 16,
+		Right = 32
 	};
 
 	KOSD();
 	~KOSD();
 
 public slots:
-	void setPosition( Position );
-	void setDisplayTime( u_int );
+	void setPosition(int position);
+	void setDisplayTime( uint );
 	void setTextColor( const QColor& );
 	void setTextFont( const QFont& );
 	void showText( const QString& );
@@ -43,25 +51,25 @@ public slots:
 	void setVolume( int );
 
 private slots:
-	void _showLabel();
-	void _setPosition();
-	QString _volumeString();
-	QString _statusString();
+	void showLabel();
+	void setPosition();
+	QString volumeString();
+	QString statusString();
 
 protected:
 	virtual void updateMask(void);
 
 protected:
-	Position _position;
-	Status _status;
-	QFont _font;
-	QColor _color;
-	int _displayTime;
-	int _volume;
+	int position;
+	Status status;
+	QFont font;
+	QColor color;
+	int displayTime;
+	int volume;
 
-	QString _lastMessage;
+	QString lastMessage;
 
-	QTimer *_displayTimer;
+	QTimer *displayTimer;
 };
 
 #endif
