@@ -17,9 +17,11 @@
 // AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
 // CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
+#include <klocale.h>
 #include "jefferson.h"
 
 extern "C" Plugin *create_plugin()
 {
+	KGlobal::locale()->insertCatalogue("jefferson");
 	return new Jefferson;
 }
