@@ -395,7 +395,7 @@ void RendererList::load(const QDomElement &e)
 		r->load(child);
 		mRendererList.append(r);
 	}
-	
+
 	unlock();
 }
 
@@ -410,18 +410,18 @@ RendererListConfigurator::RendererListConfigurator(RendererList *l, QWidget *par
 	: QWidget(parent), mList(l)
 {
 	(new QVBoxLayout(this))->setAutoAdd(true);
-	mErase=new QCheckBox(noTr("&Erase Between Frames"), this);
+	mErase=new QCheckBox(i18n("&Erase between frames"), this);
 	connect(mErase, SIGNAL(toggled(bool)), SLOT(eraseOn(bool)));
 	mErase->setChecked(mList->mClearAfter);
-	
+
 	if (nex->rendererList()==l)
 	{
-		QCheckBox *mConvolve=new QCheckBox(noTr("&Convolve Audio"), this);
+		QCheckBox *mConvolve=new QCheckBox(i18n("&Convolve audio"), this);
 		connect(mConvolve, SIGNAL(toggled(bool)), SLOT(convolve(bool)));
 		mConvolve->setChecked(nex->input()->convolve());
 	}
 	
-	new QLabel(noTr("Comments"), this);
+	new QLabel(i18n("Comments"), this);
 	
 	mComments=new QMultiLineEdit(this);
 	mComments->setText(l->mComments);
@@ -569,7 +569,7 @@ int main(int argc, char **argv)
 	runLock.lock();
 #endif
 	
-	KAboutData aboutData("nex", I18N_NOOP("Nex"), "0.0.1", 
+	KAboutData aboutData("nex", I18N_NOOP("Nex"), "0.0.1",
 		I18N_NOOP("The awesome customizable scope"),
 		KAboutData::License_LGPL, "(C) 2001 Charles Samuels", 0,
 		"http://noatun.kde.org");
