@@ -11,12 +11,13 @@
 #include <kprocess.h>
 #include <kmessagebox.h>
 #include <klocale.h>
-#include <kstddirs.h>
+#include <kstandarddirs.h>
 
 extern "C"
 {
 Plugin *create_plugin()
 {
+	KGlobal::locale()->insertCatalogue("synaescope");
 	return new SynaeScope();
 }
 }
@@ -40,7 +41,7 @@ void SynaeScope::init()
 	// for two separate checks.
 	if(!process.start(KProcess::NotifyOnExit, (KProcess::Communication)(KProcess::Stdin | KProcess::Stdout)))
 	{
-		KMessageBox::error(0, i18n("Could not start noatunsynaescope.  Check your installation."));
+		KMessageBox::error(0, i18n("Unable to start noatunsynaescope. Check your installation."));
 		unload();
 	}
 
